@@ -1,6 +1,5 @@
 /*
  *  xfce4-mailwatch-plugin - a mail notification applet for the xfce4 panel
- *  Copyright (c) 2013 Ján Sučan <sucan@runbox.com>
  *  Copyright (c) 2005 Pasi Orovuo <pasi.ov@gmail.com>
  *  Copyright (c) 2008 Brian Tarricone <bjt23@cornell.edu>
  *
@@ -489,7 +488,7 @@ mh_check_mail_timeout(gpointer data)
         return TRUE;
     }
 
-    th = g_thread_create( mh_main_thread, mh, FALSE, NULL );
+    th = g_thread_try_new( NULL, mh_main_thread, mh, NULL );
     g_atomic_pointer_set( &mh->thread, th );
 
     return TRUE;
@@ -572,10 +571,10 @@ mh_get_setup_page( XfceMailwatchMailbox *mailbox )
     GtkWidget               *vbox, *hbox;
     GtkWidget               *label, *spinner;
 
-    vbox = gtk_vbox_new( FALSE, BORDER );
+    vbox = gtk_box_new( GTK_ORIENTATION_VERTICAL, BORDER );
     gtk_widget_show( vbox );
 
-    hbox = gtk_hbox_new( FALSE, BORDER );
+    hbox = gtk_box_new( GTK_ORIENTATION_HORIZONTAL, BORDER );
     gtk_widget_show( hbox );
     gtk_box_pack_start( GTK_BOX( vbox ), hbox, FALSE, FALSE, 0 );
     
@@ -584,13 +583,13 @@ mh_get_setup_page( XfceMailwatchMailbox *mailbox )
     gtk_widget_show( label );
     gtk_box_pack_start( GTK_BOX( hbox ), label, FALSE, FALSE, 0 );
 
-    hbox = gtk_hbox_new( FALSE, BORDER );
+    hbox = gtk_box_new( GTK_ORIENTATION_HORIZONTAL, BORDER );
     gtk_widget_show( hbox );
     gtk_box_pack_start( GTK_BOX( vbox ), hbox, FALSE, FALSE, 0 );
     
     label = gtk_label_new_with_mnemonic( _( "_Interval:" ) );
     gtk_widget_show( label );
-    gtk_misc_set_alignment( GTK_MISC( label ), 1, 0.5 );
+    gtk_label_set_xalign( GTK_LABEL( label ), 1.0 );
     gtk_box_pack_start( GTK_BOX( hbox ), label, FALSE, FALSE, 0 );
 
     spinner = gtk_spin_button_new_with_range( 1.0, 1440.0, 1.0 );
