@@ -1,6 +1,5 @@
 /*
  *  xfce4-mailwatch-plugin - a mail notification applet for the xfce4 panel
- *  Copyright (c) 2013 Ján Sučan <sucan@runbox.com>
  *  Copyright (c) 2008 Brian Tarricone <bjt23@cornell.edu>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -62,7 +61,6 @@
 #include <libxfce4util/libxfce4util.h>
 
 #ifdef HAVE_SSL_SUPPORT
-#include <gcrypt.h>
 #include <gnutls/gnutls.h>
 #endif
 
@@ -122,85 +120,8 @@ typedef enum
 
 
 #ifdef HAVE_SSL_SUPPORT
-
-/* missing from 1.2.0? */
-#ifndef _GCRY_PTH_SOCKADDR
-#define _GCRY_PTH_SOCKADDR  struct sockaddr
-#endif
-#ifndef _GCRY_PTH_SOCKLEN_T
-#define _GCRY_PTH_SOCKLEN_T socklen_t
-#endif
-
 #define GNUTLS_CA_FILE           "ca.pem"
-    
-/* stuff to support 'gthreads' with gcrypt */
-static int my_g_mutex_init(void **priv);
-static int my_g_mutex_destroy(void **priv);
-static int my_g_mutex_lock(void **priv);
-static int my_g_mutex_unlock(void **priv);
-static struct gcry_thread_cbs gcry_threads_gthread = {
-    GCRY_THREAD_OPTION_USER,
-    NULL,
-    my_g_mutex_init,
-    my_g_mutex_destroy,
-    my_g_mutex_lock,
-    my_g_mutex_unlock,
-    read,
-    write,
-    (ssize_t (*)(int, fd_set *, fd_set *, fd_set *, struct timeval *))select,
-    (ssize_t (*)(pid_t, int *, int))waitpid,
-    accept,
-    (int (*)(int, _GCRY_PTH_SOCKADDR *, _GCRY_PTH_SOCKLEN_T))connect,
-    (int (*)(int, const struct msghdr *, int))sendmsg,
-    (int (*)(int, struct msghdr *, int))recvmsg
-};
 
-/*
- * gthread -> gcrypt support wrappers
- */
-static int
-my_g_mutex_init(void **priv)
-{
-    GMutex **gmx = (GMutex **)priv;
-    
-    *gmx = g_mutex_new();
-    if(!*gmx)
-        return -1;
-    return 0;
-}
-
-static int
-my_g_mutex_destroy(void **priv)
-{
-    GMutex **gmx = (GMutex **)priv;
-    
-    g_mutex_free(*gmx);
-    return 0;
-}
-
-static int
-my_g_mutex_lock(void **priv)
-{
-    GMutex **gmx = (GMutex **)priv;
-    
-    g_mutex_lock(*gmx);
-    return 0;
-}
-
-static int
-my_g_mutex_unlock(void **priv)
-{
-    GMutex **gmx = (GMutex **)priv;
-    
-    g_mutex_unlock(*gmx);
-    return 0;
-}
-
-#endif  /* defined(HAVE_SSL_SUPPORT) */
-
-
-
-#ifdef HAVE_SSL_SUPPORT
 static gboolean
 xfce_mailwatch_net_conn_tls_handshake(XfceMailwatchNetConn *net_conn,
                                       GError **error)
@@ -365,7 +286,6 @@ xfce_mailwatch_net_conn_init(void)
 
     if(!__inited) {
 #ifdef HAVE_SSL_SUPPORT
-        gcry_control(GCRYCTL_SET_THREAD_CBS, &gcry_threads_gthread);
         gnutls_global_init();
 #endif
         __inited = TRUE;
@@ -618,7 +538,7 @@ xfce_mailwatch_net_conn_make_secure(XfceMailwatchNetConn *net_conn,
     gnutls_credentials_set(net_conn->gt_session, GNUTLS_CRD_CERTIFICATE,
                            net_conn->gt_creds);
     gnutls_transport_set_ptr(net_conn->gt_session,
-                             (gnutls_transport_ptr_t)net_conn->fd);
+                             (gnutls_transport_ptr_t)GINT_TO_POINTER(net_conn->fd));
 #if GNUTLS_VERSION_NUMBER < 0x020c00 
     if(fcntl(net_conn->fd, F_GETFL) & O_NONBLOCK)
         gnutls_transport_set_lowat(net_conn->gt_session, 0);
